pub struct DurationValidatorBuilder<S: State = Empty> { /* private fields */ }Expand description
Builder for DurationValidator.
Implementations
Sourceimpl<S: State> DurationValidatorBuilder<S>
impl<S: State> DurationValidatorBuilder<S>
Sourcepub fn with_error_messages(
self,
error_messages: impl IntoIterator<Item = (DurationViolation, impl Into<FixedStr>)>,
) -> DurationValidatorBuilder<SetErrorMessages<S>>where
S::ErrorMessages: IsUnset,
pub fn with_error_messages(
self,
error_messages: impl IntoIterator<Item = (DurationViolation, impl Into<FixedStr>)>,
) -> DurationValidatorBuilder<SetErrorMessages<S>>where
S::ErrorMessages: IsUnset,
Adds a map with custom error messages to the underlying validator.
If a violation has no custom error message attached to it, it uses the default error message.
Sourcepub fn cel(self, program: CelProgram) -> DurationValidatorBuilder<S>
pub fn cel(self, program: CelProgram) -> DurationValidatorBuilder<S>
Adds a CelProgram to this validator.
Sourcepub fn ignore_always(self) -> DurationValidatorBuilder<SetIgnore<S>>where
S::Ignore: IsUnset,
pub fn ignore_always(self) -> DurationValidatorBuilder<SetIgnore<S>>where
S::Ignore: IsUnset,
Specifies that this validator should always be ignored.
Sourcepub fn required(self) -> DurationValidatorBuilder<SetRequired<S>>where
S::Required: IsUnset,
pub fn required(self) -> DurationValidatorBuilder<SetRequired<S>>where
S::Required: IsUnset,
Specifies that the field must be set in order to be valid.
Sourcepub fn in_(
self,
val: impl IntoSortedList<Duration>,
) -> DurationValidatorBuilder<SetIn<S>>where
S::In: IsUnset,
pub fn in_(
self,
val: impl IntoSortedList<Duration>,
) -> DurationValidatorBuilder<SetIn<S>>where
S::In: IsUnset,
Specifies that only the values in this list will be considered valid for this field.
Sourcepub fn not_in(
self,
val: impl IntoSortedList<Duration>,
) -> DurationValidatorBuilder<SetNotIn<S>>where
S::NotIn: IsUnset,
pub fn not_in(
self,
val: impl IntoSortedList<Duration>,
) -> DurationValidatorBuilder<SetNotIn<S>>where
S::NotIn: IsUnset,
Specifies that the values in this list will be considered NOT valid for this field.
Sourcepub fn const_(self, val: Duration) -> DurationValidatorBuilder<SetConst<S>>where
S::Const: IsUnset,
pub fn const_(self, val: Duration) -> DurationValidatorBuilder<SetConst<S>>where
S::Const: IsUnset,
Specifies that only this specific value will be considered valid for this field.
Sourcepub fn lt(self, val: Duration) -> DurationValidatorBuilder<SetLt<S>>where
S::Lt: IsUnset,
pub fn lt(self, val: Duration) -> DurationValidatorBuilder<SetLt<S>>where
S::Lt: IsUnset,
Specifies that the duration must be shorter than the indicated amount in order to pass validation.
Sourcepub fn lte(self, val: Duration) -> DurationValidatorBuilder<SetLte<S>>where
S::Lte: IsUnset,
pub fn lte(self, val: Duration) -> DurationValidatorBuilder<SetLte<S>>where
S::Lte: IsUnset,
Specifies that the duration must be equal to or shorter than the indicated amount in order to pass validation.
Sourcepub fn gt(self, val: Duration) -> DurationValidatorBuilder<SetGt<S>>where
S::Gt: IsUnset,
pub fn gt(self, val: Duration) -> DurationValidatorBuilder<SetGt<S>>where
S::Gt: IsUnset,
Specifies that the duration must be longer than the indicated amount in order to pass validation.
Sourcepub fn gte(self, val: Duration) -> DurationValidatorBuilder<SetGte<S>>where
S::Gte: IsUnset,
pub fn gte(self, val: Duration) -> DurationValidatorBuilder<SetGte<S>>where
S::Gte: IsUnset,
Specifies that the duration must be equal to or longer than the indicated amount in order to pass validation.
Sourcepub fn build(self) -> DurationValidator
pub fn build(self) -> DurationValidator
Builds the validator.