ValidationResultExt

Trait ValidationResultExt 

pub trait ValidationResultExt {
    // Required methods
    fn is_valid(&self) -> bool;
    fn is_fail_fast(&self) -> bool;
}
Utility sealed trait for ValidationResult that makes it easier to discern the validation status.

Required Methods

fn is_valid(&self) -> bool

Returns true if the result is Ok and IsValid::Yes, and false otherwise.

fn is_fail_fast(&self) -> bool

Checks if the result is Err with FailFast.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors