pub trait AsProtoField {
// Required method
fn as_proto_field() -> FieldType;
}Expand description
A trait that specifies the protobuf field type to which a rust type should be mapped (i.e. single, optional, repeated, map).
Automatically implemented for the types that implement AsProtoType.
Required Methods
fn as_proto_field() -> FieldType
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.