pub trait ValidationResultExt {
// Required methods
fn is_valid(&self) -> bool;
fn is_fail_fast(&self) -> bool;
}Expand description
Utility sealed trait for ValidationResult that makes it easier to discern the validation status.
Required Methods
Sourcefn is_valid(&self) -> bool
fn is_valid(&self) -> bool
Returns true if the result is Ok and IsValid::Yes, and false otherwise.
Sourcefn is_fail_fast(&self) -> bool
fn is_fail_fast(&self) -> bool
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.